---
title: rmtoo Presentations
---

The following presentations about *rmtoo* are available:

* [Introduction](../../../assets/presentations/rmtooIntroductionV7.pdf)
* [Details](../../../assets/presentations/rmtooDetailsV3.pdf)

[Here](http://www.jiludwig.com/Requirements_Management_Tools.html)
are more tools.

*Update 2020-02-27:* there are spreadsheet (Excel) import and export features
available now.
